@@ -1,38 +1,18 @@
-//@line 40 "/builds/slave/m-2.0-lnx-xr/build/toolkit/components/viewsource/content/viewSource.js"
+//@line 39 "/builds/slave/rel-m-192-xr-lnx-bld/build/toolkit/components/viewsource/content/viewSource.js"
 
 const Cc = Components.classes;
 const Ci = Components.interfaces;
+const Cr = Components.results;
+const pageLoaderIface = Components.interfaces.nsIWebPageDescriptor;
+const nsISelectionPrivate = Components.interfaces.nsISelectionPrivate;
+const nsISelectionController = Components.interfaces.nsISelectionController;
+var gBrowser = null;
+var gViewSourceBundle = null;
 var gPrefs = null;
 
 var gLastLineFound = '';
 var gGoToLine = 0;
 
-[
-  ["gBrowser",          "content"],
-  ["gViewSourceBundle", "viewSourceBundle"]
-].forEach(function ([name, id]) {
-  window.__defineGetter__(name, function () {
-    var element = document.getElementById(id);
-    if (!element)
-      return null;
-    delete window[name];
-    return window[name] = element;
-  });
-});
-
-// viewZoomOverlay.js uses this
-function getBrowser() {
-  return gBrowser;
-}
-
-__defineGetter__("gPageLoader", function () {
-  var webnav = getWebNavigation();
-  if (!webnav)
-    return null;
-  delete this.gPageLoader;
-  return this.gPageLoader = webnav.QueryInterface(Ci.nsIWebPageDescriptor);
-});
-
 try {
   var prefService = Components.classes["@mozilla.org/preferences-service;1"]
                               .getService(Components.interfaces.nsIPrefService);
@@ -51,16 +31,45 @@ var gSelectionListener = {
   }
 }
 
+var gViewSourceProgressListener = {
+
+  QueryInterface: function (aIID) {
+    if (aIID.equals(Ci.nsIWebProgressListener) ||
+        aIID.equals(Ci.nsISupportsWeakReference))
+      return this;
+    throw Cr.NS_NOINTERFACE;
+  },
+
+  onStateChange: function (aWebProgress, aRequest, aStateFlags, aStatus) {
+  },
+
+  onProgressChange: function (aWebProgress, aRequest,
+                              aCurSelfProgress, aMaxSelfProgress,
+                              aCurTotalProgress, aMaxTotalProgress) {
+  },
+
+  onLocationChange: function (aWebProgress, aRequest, aLocationURI) {
+    UpdateBackForwardCommands(getBrowser().webNavigation);
+  },
+
+  onStatusChange: function (aWebProgress, aRequest, aStatus, aMessage) {
+  },
+
+  onSecurityChange: function (aWebProgress, aRequest, aState) {
+  }
+
+}
+
 function onLoadViewSource() 
 {
   viewSource(window.arguments[0]);
   document.commandDispatcher.focusedWindow = content;
-  gBrowser.droppedLinkHandler = function (event, url, name) {
-    viewSource(url)
-    event.preventDefault();
-  }
-
-  if (!isHistoryEnabled()) {
+      
+  if (isHistoryEnabled()) {
+    // Attach the progress listener.
+    getBrowser().addProgressListener(gViewSourceProgressListener, 
+        Components.interfaces.nsIWebProgress.NOTIFY_ALL);
+  } else {
     // Disable the BACK and FORWARD commands and hide the related menu items.
     var viewSourceNavigation = document.getElementById("viewSourceNavigation");
     viewSourceNavigation.setAttribute("disabled", "true");
@@ -68,41 +77,65 @@ function onLoadViewSource()
   }
 }
 
-function isHistoryEnabled() {
-  return !gBrowser.hasAttribute("disablehistory");
+function onUnloadViewSource() 
+{
+  // Detach the progress listener.
+  if (isHistoryEnabled()) {
+    getBrowser().removeProgressListener(gViewSourceProgressListener);
+  }
 }
 
-function getSelectionController() {
-  return gBrowser.docShell
-                 .QueryInterface(Ci.nsIInterfaceRequestor)
-                 .getInterface(Ci.nsISelectionDisplay)
-                 .QueryInterface(Ci.nsISelectionController);
+function isHistoryEnabled() {
+  return !getBrowser().hasAttribute("disablehistory");
+}
+
+function getBrowser()
+{
+  if (!gBrowser)
+    gBrowser = document.getElementById("content");
+  return gBrowser;
+}
+
+function getSelectionController()
+{
+  return getBrowser().docShell
+    .QueryInterface(Components.interfaces.nsIInterfaceRequestor)
+    .getInterface(Components.interfaces.nsISelectionDisplay)
+    .QueryInterface(nsISelectionController);
+
+}
+
+function getViewSourceBundle()
+{
+  if (!gViewSourceBundle)
+    gViewSourceBundle = document.getElementById("viewSourceBundle");
+  return gViewSourceBundle;
 }
 
 function viewSource(url)
 {
   if (!url)
-    return; // throw Components.results.NS_ERROR_FAILURE;
+    return false; // throw Components.results.NS_ERROR_FAILURE;
     
   var viewSrcUrl = "view-source:" + url;
 
-  gBrowser.addEventListener("pagehide", onUnloadContent, true);
-  gBrowser.addEventListener("pageshow", onLoadContent, true);
-  gBrowser.addEventListener("command", onCommandContent, false);
+  getBrowser().addEventListener("unload", onUnloadContent, true);
+  getBrowser().addEventListener("load", onLoadContent, true);
 
   var loadFromURL = true;
-
+  //
   // Parse the 'arguments' supplied with the dialog.
   //    arg[0] - URL string.
   //    arg[1] - Charset value in the form 'charset=xxx'.
   //    arg[2] - Page descriptor used to load content from the cache.
   //    arg[3] - Line number to go to.
   //    arg[4] - Whether charset was forced by the user
-
+  //
   if ("arguments" in window) {
     var arg;
-
+    //
     // Set the charset of the viewsource window...
+    //
     var charset;
     if (window.arguments.length >= 2) {
       arg = window.arguments[1];
@@ -126,31 +159,38 @@ function viewSource(url)
 
       try {
         if (arg === true) {
-          var docCharset = gBrowser.docShell.QueryInterface(Ci.nsIDocCharset);
+          var docCharset = getBrowser().docShell.QueryInterface
+                             (Components.interfaces.nsIDocCharset);
           docCharset.charset = charset;
         }
       } catch (ex) {
         // Ignore the failure and keep processing arguments...
       }
     }
-
+    //
     // Get any specified line to jump to.
+    //
     if (window.arguments.length >= 4) {
       arg = window.arguments[3];
       gGoToLine = parseInt(arg);
     }
-
+    //
     // Use the page descriptor to load the content from the cache (if
     // available).
+    //
     if (window.arguments.length >= 3) {
       arg = window.arguments[2];
 
       try {
         if (typeof(arg) == "object" && arg != null) {
+          var PageLoader = getBrowser().webNavigation.QueryInterface(pageLoaderIface);
+
+          //
           // Load the page using the page descriptor rather than the URL.
           // This allows the content to be fetched from the cache (if
           // possible) rather than the network...
-          gPageLoader.loadPage(arg, gPageLoader.DISPLAY_AS_SOURCE);
+          //
+          PageLoader.loadPage(arg, pageLoaderIface.DISPLAY_AS_SOURCE);
 
           // The content was successfully loaded.
           loadFromURL = false;
@@ -162,9 +202,9 @@ function viewSource(url)
           shEntry.setTitle(viewSrcUrl);
           shEntry.loadType = Ci.nsIDocShellLoadInfo.loadHistory;
           shEntry.cacheKey = shEntrySource.cacheKey;
-          gBrowser.sessionHistory
-                  .QueryInterface(Ci.nsISHistoryInternal)
-                  .addEntry(shEntry, true);
+          getBrowser().webNavigation.sessionHistory
+                      .QueryInterface(Ci.nsISHistoryInternal)
+                      .addEntry(shEntry, true);
         }
       } catch(ex) {
         // Ignore the failure.  The content will be loaded via the URL
@@ -174,24 +214,24 @@ function viewSource(url)
   }
 
   if (loadFromURL) {
+    //
     // Currently, an exception is thrown if the URL load fails...
-    var loadFlags = Ci.nsIWebNavigation.LOAD_FLAGS_NONE;
-    getWebNavigation().loadURI(viewSrcUrl, loadFlags, null, null, null);
+    //
+    var loadFlags = Components.interfaces.nsIWebNavigation.LOAD_FLAGS_NONE;
+    getBrowser().webNavigation.loadURI(viewSrcUrl, loadFlags, null, null, null);
   }
 
-  // Check the view_source.wrap_long_lines pref and set the menuitem's checked
-  // attribute accordingly.
+  //check the view_source.wrap_long_lines pref and set the menuitem's checked attribute accordingly
   if (gPrefs) {
     try {
       var wraplonglinesPrefValue = gPrefs.getBoolPref("view_source.wrap_long_lines");
 
       if (wraplonglinesPrefValue)
-        document.getElementById("menu_wrapLongLines").setAttribute("checked", "true");
+        document.getElementById('menu_wrapLongLines').setAttribute("checked", "true");
     } catch (ex) {
     }
     try {
-      document.getElementById("menu_highlightSyntax").setAttribute("checked",
-        gPrefs.getBoolPref("view_source.syntax_highlight"));
+      document.getElementById("menu_highlightSyntax").setAttribute("checked", gPrefs.getBoolPref("view_source.syntax_highlight"));
     } catch (ex) {
     }
   } else {
@@ -199,13 +239,16 @@ function viewSource(url)
   }
 
   window.addEventListener("AppCommand", HandleAppCommandEvent, true);
-  window.addEventListener("MozSwipeGesture", HandleSwipeGesture, true);
   window.content.focus();
+
+  return true;
 }
 
 function onLoadContent()
 {
+  //
   // If the view source was opened with a "go to line" argument.
+  //
   if (gGoToLine > 0) {
     goToLine(gGoToLine);
     gGoToLine = 0;
@@ -214,87 +257,29 @@ function onLoadContent()
 
   // Register a listener so that we can show the caret position on the status bar.
   window.content.getSelection()
-   .QueryInterface(Ci.nsISelectionPrivate)
+   .QueryInterface(nsISelectionPrivate)
    .addSelectionListener(gSelectionListener);
   gSelectionListener.attached = true;
-
-  if (isHistoryEnabled())
-    UpdateBackForwardCommands();
 }
 
 function onUnloadContent()
 {
+  //
   // Disable "go to line" while reloading due to e.g. change of charset
   // or toggling of syntax highlighting.
+  //
   document.getElementById('cmd_goToLine').setAttribute('disabled', 'true');
 
   // If we're not just unloading the initial "about:blank" which doesn't have
   // a selection listener, get rid of it so it doesn't try to fire after the
   // window has gone away.
   if (gSelectionListener.attached) {
-    window.content.getSelection().QueryInterface(Ci.nsISelectionPrivate)
+    window.content.getSelection().QueryInterface(nsISelectionPrivate)
           .removeSelectionListener(gSelectionListener);
     gSelectionListener.attached = false;
   }
 }
 
-/**
- * Handle command events bubbling up from error page content
- */
-function onCommandContent(event) {
-  // Don't trust synthetic events
-  if (!event.isTrusted)
-    return;
-
-  var target = event.originalTarget;
-  var errorDoc = target.ownerDocument;
-  
-  var formatter = Cc["@mozilla.org/toolkit/URLFormatterService;1"]
-                    .getService(Ci.nsIURLFormatter);
-
-  if (/^about:blocked/.test(errorDoc.documentURI)) {
-    // The event came from a button on a malware/phishing block page
-    // First check whether it's malware or phishing, so that we can
-    // use the right strings/links
-    var isMalware = /e=malwareBlocked/.test(errorDoc.documentURI);
-    
-    if (target == errorDoc.getElementById('getMeOutButton')) {
-      // Instead of loading some safe page, just close the window
-      window.close();
-    } else if (target == errorDoc.getElementById('reportButton')) {
-      // This is the "Why is this site blocked" button.  For malware,
-      // we can fetch a site-specific report, for phishing, we redirect
-      // to the generic page describing phishing protection.
-
-      if (isMalware) {
-        // Get the stop badware "why is this blocked" report url,
-        // append the current url, and go there.
-        try {
-          let reportURL = formatter.formatURLPref("browser.safebrowsing.malware.reportURL", true);
-          reportURL += errorDoc.location.href.slice(12);
-          openURL(reportURL);
-        } catch (e) {
-          Components.utils.reportError("Couldn't get malware report URL: " + e);
-        }
-      } else { // It's a phishing site, not malware
-        try {
-          var infoURL = formatter.formatURLPref("browser.safebrowsing.warning.infoURL", true);
-          openURL(infoURL);
-        } catch (e) {
-          Components.utils.reportError("Couldn't get phishing info URL: " + e);
-        }
-      }
-    } else if (target == errorDoc.getElementById('ignoreWarningButton')) {
-      // Allow users to override and continue through to the site,
-      // but add a notify bar as a reminder, so that they don't lose
-      // track after, e.g., tab switching.
-      gBrowser.loadURIWithFlags(content.location.href,
-                                Ci.nsIWebNavigation.LOAD_FLAGS_BYPASS_CLASSIFIER,
-                                null, null, null);
-    }
-  }
-}
-
 function HandleAppCommandEvent(evt)
 {
   evt.stopPropagation();
@@ -308,24 +293,6 @@ function HandleAppCommandEvent(evt)
   }
 }
 
-function HandleSwipeGesture(evt) {
-  evt.stopPropagation();
-  switch (evt.direction) {
-    case SimpleGestureEvent.DIRECTION_LEFT:
-      BrowserBack();
-      break;
-    case SimpleGestureEvent.DIRECTION_RIGHT:
-      BrowserForward();
-      break;
-    case SimpleGestureEvent.DIRECTION_UP:
-      goDoCommand("cmd_scrollTop");
-      break;
-    case SimpleGestureEvent.DIRECTION_DOWN:
-      goDoCommand("cmd_scrollBottom");
-      break;
-  }
-}
-
 function ViewSourceClose()
 {
   window.close();
@@ -333,8 +300,14 @@ function ViewSourceClose()
 
 function ViewSourceReload()
 {
-  gBrowser.reloadWithFlags(Ci.nsIWebNavigation.LOAD_FLAGS_BYPASS_PROXY |
-                           Ci.nsIWebNavigation.LOAD_FLAGS_BYPASS_CACHE);
+  const webNavigation = getBrowser().webNavigation;
+  webNavigation.reload(webNavigation.LOAD_FLAGS_BYPASS_PROXY | webNavigation.LOAD_FLAGS_BYPASS_CACHE);
+}
+
+// Strips the |view-source:| for editPage()
+function ViewSourceEditPage()
+{
+  editPage(window.content.location.href.substring(12), window, false);
 }
 
 // Strips the |view-source:| for saveURL()
@@ -343,34 +316,26 @@ function ViewSourceSavePage()
   saveURL(window.content.location.href.substring(12), null, "SaveLinkTitle");
 }
 
-var PrintPreviewListener = {
-  getPrintPreviewBrowser: function () {
-    var browser = document.getElementById("ppBrowser");
-    if (!browser) {
-      browser = document.createElement("browser");
-      browser.setAttribute("id", "ppBrowser");
-      browser.setAttribute("flex", "1");
-      document.getElementById("appcontent").
-        insertBefore(browser, document.getElementById("FindToolbar"));
-    }
-    return browser;
-  },
-  getSourceBrowser: function () {
-    return gBrowser;
-  },
-  getNavToolbox: function () {
-    return document.getElementById("appcontent");
-  },
-  onEnter: function () {
-    var toolbox = document.getElementById("viewSource-toolbox");
-    toolbox.hidden = true;
-    gBrowser.collapsed = true;
-  },
-  onExit: function () {
-    document.getElementById("ppBrowser").collapsed = true;
-    gBrowser.collapsed = false;
-    document.getElementById("viewSource-toolbox").hidden = false;
-  }
+function onEnterPP()
+{
+  var toolbox = document.getElementById("viewSource-toolbox");
+  toolbox.hidden = true;
+}
+
+function onExitPP()
+{
+  var toolbox = document.getElementById("viewSource-toolbox");
+  toolbox.hidden = false;
+}
+
+function getPPBrowser()
+{
+  return document.getElementById("content");
+}
+
+function getNavToolbox()
+{
+  return document.getElementById("appcontent");
 }
 
 function getWebNavigation()
@@ -384,40 +349,41 @@ function getWebNavigation()
 
 function ViewSourceGoToLine()
 {
-  var promptService = Cc["@mozilla.org/embedcomp/prompt-service;1"]
-                        .getService(Ci.nsIPromptService);
+  var promptService = Components.classes["@mozilla.org/embedcomp/prompt-service;1"]
+        .getService(Components.interfaces.nsIPromptService);
+  var viewSourceBundle = getViewSourceBundle();
 
   var input = {value:gLastLineFound};
   for (;;) {
     var ok = promptService.prompt(
         window,
-        gViewSourceBundle.getString("goToLineTitle"),
-        gViewSourceBundle.getString("goToLineText"),
+        viewSourceBundle.getString("goToLineTitle"),
+        viewSourceBundle.getString("goToLineText"),
         input,
         null,
         {value:0});
 
-    if (!ok)
-      return;
+    if (!ok) return;
 
     var line = parseInt(input.value, 10);
-
+ 
     if (!(line > 0)) {
       promptService.alert(window,
-                          gViewSourceBundle.getString("invalidInputTitle"),
-                          gViewSourceBundle.getString("invalidInputText"));
-
+          viewSourceBundle.getString("invalidInputTitle"),
+          viewSourceBundle.getString("invalidInputText"));
+  
       continue;
     }
 
     var found = goToLine(line);
 
-    if (found)
+    if (found) {
       break;
+    }
 
     promptService.alert(window,
-                        gViewSourceBundle.getString("outOfRangeTitle"),
-                        gViewSourceBundle.getString("outOfRangeText"));
+        viewSourceBundle.getString("outOfRangeTitle"),
+        viewSourceBundle.getString("outOfRangeText"));
   }
 }
 
@@ -425,11 +391,12 @@ function goToLine(line)
 {
   var viewsource = window.content.document.body;
 
+  //
   // The source document is made up of a number of pre elements with
   // id attributes in the format <pre id="line123">, meaning that
   // the first line in the pre element is number 123.
   // Do binary search to find the pre element containing the line.
-
+  //
   var pre;
   for (var lbound = 0, ubound = viewsource.childNodes.length; ; ) {
     var middle = (lbound + ubound) >> 1;
@@ -462,7 +429,7 @@ function goToLine(line)
   // Tune the selection at the beginning of the next line and do some tweaking
   // to position the focusNode and the caret at the beginning of the line.
 
-  selection.QueryInterface(Ci.nsISelectionPrivate)
+  selection.QueryInterface(nsISelectionPrivate)
     .interlinePosition = true;
 
   selection.addRange(result.range);
@@ -487,19 +454,19 @@ function goToLine(line)
   }
 
   var selCon = getSelectionController();
-  selCon.setDisplaySelection(Ci.nsISelectionController.SELECTION_ON);
+  selCon.setDisplaySelection(nsISelectionController.SELECTION_ON);
   selCon.setCaretVisibilityDuringSelection(true);
 
   // Scroll the beginning of the line into view.
   selCon.scrollSelectionIntoView(
-    Ci.nsISelectionController.SELECTION_NORMAL,
-    Ci.nsISelectionController.SELECTION_FOCUS_REGION,
+    nsISelectionController.SELECTION_NORMAL,
+    nsISelectionController.SELECTION_FOCUS_REGION,
     true);
 
   gLastLineFound = line;
 
   document.getElementById("statusbar-line-col").label =
-    gViewSourceBundle.getFormattedString("statusBarLineCol", [line, 1]);
+    getViewSourceBundle().getFormattedString("statusBarLineCol", [line, 1]);
 
   return true;
 }
@@ -521,20 +488,21 @@ function updateStatusBar()
   }
 
   var selCon = getSelectionController();
-  selCon.setDisplaySelection(Ci.nsISelectionController.SELECTION_ON);
+  selCon.setDisplaySelection(nsISelectionController.SELECTION_ON);
   selCon.setCaretVisibilityDuringSelection(true);
 
-  var interlinePosition = selection.QueryInterface(Ci.nsISelectionPrivate)
-                                   .interlinePosition;
+  var interlinePosition = selection
+      .QueryInterface(nsISelectionPrivate).interlinePosition;
 
   var result = {};
   findLocation(null, -1, 
       selection.focusNode, selection.focusOffset, interlinePosition, result);
 
-  statusBarField.label = gViewSourceBundle.getFormattedString(
-                           "statusBarLineCol", [result.line, result.col]);
+  statusBarField.label = getViewSourceBundle()
+      .getFormattedString("statusBarLineCol", [result.line, result.col]);
 }
 
+//
 // Loops through the text lines in the pre element. The arguments are either
 // (pre, line) or (node, offset, interlinePosition). result is an out
 // argument. If (pre, line) are specified (and node == null), result.range is
@@ -542,25 +510,34 @@ function updateStatusBar()
 // interlinePosition) are specified, result.line and result.col are the line
 // and column number of the specified offset in the specified node relative to
 // the whole file.
+//
 function findLocation(pre, line, node, offset, interlinePosition, result)
 {
   if (node && !pre) {
+    //
     // Look upwards to find the current pre element.
+    //
     for (pre = node;
          pre.nodeName != "PRE";
          pre = pre.parentNode);
   }
 
+  //
   // The source document is made up of a number of pre elements with
   // id attributes in the format <pre id="line123">, meaning that
   // the first line in the pre element is number 123.
+  //
   var curLine = parseInt(pre.id.substring(4));
 
+  //
   // Walk through each of the text nodes and count newlines.
+  //
   var treewalker = window.content.document
       .createTreeWalker(pre, NodeFilter.SHOW_TEXT, null, false);
 
+  //
   // The column number of the first character in the current text node.
+  //
   var firstCol = 1;
 
   var found = false;
@@ -568,11 +545,15 @@ function findLocation(pre, line, node, offset, interlinePosition, result)
        textNode && !found;
        textNode = treewalker.nextNode()) {
 
+    //
     // \r is not a valid character in the DOM, so we only check for \n.
+    //
     var lineArray = textNode.data.split(/\n/);
     var lastLineInNode = curLine + lineArray.length - 1;
 
+    //
     // Check if we can skip the text node without further inspection.
+    //
     if (node ? (textNode != node) : (lastLineInNode < line)) {
       if (lineArray.length > 1) {
         firstCol = 1;
@@ -582,8 +563,10 @@ function findLocation(pre, line, node, offset, interlinePosition, result)
       continue;
     }
 
+    //
     // curPos is the offset within the current text node of the first
     // character in the current line.
+    //
     for (var i = 0, curPos = 0;
          i < lineArray.length;
          curPos += lineArray[i++].length + 1) {
@@ -594,14 +577,16 @@ function findLocation(pre, line, node, offset, interlinePosition, result)
 
       if (node) {
         if (offset >= curPos && offset <= curPos + lineArray[i].length) {
+          //
           // If we are right after the \n of a line and interlinePosition is
           // false, the caret looks as if it were at the end of the previous
           // line, so we display that line and column instead.
-
+          //
           if (i > 0 && offset == curPos && !interlinePosition) {
             result.line = curLine - 1;
             var prevPos = curPos - lineArray[i - 1].length;
             result.col = (i == 1 ? firstCol : 1) + offset - prevPos;
+
           } else {
             result.line = curLine;
             result.col = (i == 0 ? firstCol : 1) + offset - curPos;
@@ -616,9 +601,11 @@ function findLocation(pre, line, node, offset, interlinePosition, result)
           result.range = document.createRange();
           result.range.setStart(textNode, curPos);
 
+          //
           // This will always be overridden later, except when we look for
           // the very last line in the file (this is the only line that does
           // not end with \n).
+          //
           result.range.setEndAfter(pre.lastChild);
 
         } else if (curLine == line + 1) {
@@ -633,8 +620,8 @@ function findLocation(pre, line, node, offset, interlinePosition, result)
   return found || ("range" in result);
 }
 
-// Toggle long-line wrapping and sets the view_source.wrap_long_lines
-// pref to persist the last state.
+//function to toggle long-line wrapping and set the view_source.wrap_long_lines 
+//pref to persist the last state
 function wrapLongLines()
 {
   var myWrap = window.content.document.body;
@@ -643,10 +630,10 @@ function wrapLongLines()
     myWrap.className = 'wrap';
   else myWrap.className = '';
 
-  // Since multiple viewsource windows are possible, another window could have
-  // affected the pref, so instead of determining the new pref value via the current
-  // pref value, we use myWrap.className.
-  if (gPrefs) {
+  //since multiple viewsource windows are possible, another window could have 
+  //affected the pref, so instead of determining the new pref value via the current
+  //pref value, we use myWrap.className  
+  if (gPrefs){
     try {
       if (myWrap.className == '') {
         gPrefs.setBoolPref("view_source.wrap_long_lines", false);
@@ -659,28 +646,31 @@ function wrapLongLines()
   }
 }
 
-// Toggles syntax highlighting and sets the view_source.syntax_highlight
-// pref to persist the last state.
+//function to toggle syntax highlighting and set the view_source.syntax_highlight
+//pref to persist the last state
 function highlightSyntax()
 {
   var highlightSyntaxMenu = document.getElementById("menu_highlightSyntax");
   var highlightSyntax = (highlightSyntaxMenu.getAttribute("checked") == "true");
   gPrefs.setBoolPref("view_source.syntax_highlight", highlightSyntax);
 
-  gPageLoader.loadPage(gPageLoader.currentDescriptor, gPageLoader.DISPLAY_NORMAL);
+  var PageLoader = getBrowser().webNavigation.QueryInterface(pageLoaderIface);
+  PageLoader.loadPage(PageLoader.currentDescriptor, pageLoaderIface.DISPLAY_NORMAL);
 }
 
 // Fix for bug 136322: this function overrides the function in
 // browser.js to call PageLoader.loadPage() instead of BrowserReloadWithFlags()
 function BrowserSetForcedCharacterSet(aCharset)
 {
-  var docCharset = gBrowser.docShell.QueryInterface(Ci.nsIDocCharset);
+  var docCharset = getBrowser().docShell.QueryInterface(Ci.nsIDocCharset);
   docCharset.charset = aCharset;
   if (isHistoryEnabled()) {
-    gPageLoader.loadPage(gPageLoader.currentDescriptor,
-                         gPageLoader.DISPLAY_NORMAL);
+    var PageLoader = getBrowser().webNavigation.QueryInterface(pageLoaderIface);
+    PageLoader.loadPage(PageLoader.currentDescriptor,
+                        pageLoaderIface.DISPLAY_NORMAL);
   } else {
-    gBrowser.reloadWithFlags(Ci.nsIWebNavigation.LOAD_FLAGS_CHARSET_CHANGE);
+    getBrowser().webNavigation
+                .reload(Ci.nsIWebNavigation.LOAD_FLAGS_CHARSET_CHANGE);
   }
 }
 
@@ -691,21 +681,24 @@ function BrowserSetForcedCharacterSet(aCharset)
 // instead of BrowserReloadWithFlags()
 function BrowserSetForcedDetector(doReload)
 {
-  gBrowser.documentCharsetInfo.forcedDetector = true; 
+  getBrowser().documentCharsetInfo.forcedDetector = true; 
   if (doReload)
   {
     if (isHistoryEnabled()) {
-      gPageLoader.loadPage(gPageLoader.currentDescriptor,
-                           gPageLoader.DISPLAY_NORMAL);
+      var PageLoader = getBrowser().webNavigation
+                                   .QueryInterface(pageLoaderIface);
+      PageLoader.loadPage(PageLoader.currentDescriptor,
+                          pageLoaderIface.DISPLAY_NORMAL);
     } else {
-      gBrowser.reloadWithFlags(Ci.nsIWebNavigation.LOAD_FLAGS_CHARSET_CHANGE);
+      getBrowser().webNavigation
+                  .reload(Ci.nsIWebNavigation.LOAD_FLAGS_CHARSET_CHANGE);
     }
   }
 }
 
 function BrowserForward(aEvent) {
   try {
-    gBrowser.goForward();
+    getBrowser().goForward();
   }
   catch(ex) {
   }
@@ -713,23 +706,30 @@ function BrowserForward(aEvent) {
 
 function BrowserBack(aEvent) {
   try {
-    gBrowser.goBack();
+    getBrowser().goBack();
   }
   catch(ex) {
   }
 }
 
-function UpdateBackForwardCommands() {
+function UpdateBackForwardCommands(aWebNavigation) {
   var backBroadcaster = document.getElementById("Browser:Back");
   var forwardBroadcaster = document.getElementById("Browser:Forward");
 
-  if (getWebNavigation().canGoBack)
-    backBroadcaster.removeAttribute("disabled");
-  else
-    backBroadcaster.setAttribute("disabled", "true");
+  var backDisabled = backBroadcaster.hasAttribute("disabled");
+  var forwardDisabled = forwardBroadcaster.hasAttribute("disabled");
 
-  if (getWebNavigation().canGoForward)
-    forwardBroadcaster.removeAttribute("disabled");
-  else
-    forwardBroadcaster.setAttribute("disabled", "true");
+  if (backDisabled == aWebNavigation.canGoBack) {
+    if (backDisabled)
+      backBroadcaster.removeAttribute("disabled");
+    else
+      backBroadcaster.setAttribute("disabled", true);
+  }
+
+  if (forwardDisabled == aWebNavigation.canGoForward) {
+    if (forwardDisabled)
+      forwardBroadcaster.removeAttribute("disabled");
+    else
+      forwardBroadcaster.setAttribute("disabled", true);
+  }
 }
