@@ -1,4 +1,4 @@
-//@line 45 "/builds/slave/2.0-lnx-xr/build/toolkit/mozapps/downloads/content/downloads.js"
+//@line 45 "/builds/slave/rel-m-192-xr-lnx-bld/build/toolkit/mozapps/downloads/content/downloads.js"
 
 ////////////////////////////////////////////////////////////////////////////////
 //// Globals
@@ -20,9 +20,6 @@ Cu.import("resource://gre/modules/PluralForm.jsm");
 const nsIDM = Ci.nsIDownloadManager;
 
 let gDownloadManager = Cc["@mozilla.org/download-manager;1"].getService(nsIDM);
-let gDownloadManagerUI = Cc["@mozilla.org/download-manager-ui;1"].
-                         getService(Ci.nsIDownloadManagerUI);
-
 let gDownloadListener = null;
 let gDownloadsView = null;
 let gSearchBox = null;
@@ -127,8 +124,6 @@ function downloadCompleted(aDownload)
 
     if (gDownloadManager.activeDownloadCount == 0)
       document.title = document.documentElement.getAttribute("statictitle");
-
-    gDownloadManagerUI.getAttention();
   }
   catch (e) { }
 }
@@ -251,7 +246,7 @@ function openDownload(aDownload)
       dontAsk = !pref.getBoolPref(PREF_BDM_ALERTONEXEOPEN);
     } catch (e) { }
 
-//@line 311 "/builds/slave/2.0-lnx-xr/build/toolkit/mozapps/downloads/content/downloads.js"
+//@line 306 "/builds/slave/rel-m-192-xr-lnx-bld/build/toolkit/mozapps/downloads/content/downloads.js"
 
     if (!dontAsk) {
       var strings = document.getElementById("downloadStrings");
@@ -272,15 +267,6 @@ function openDownload(aDownload)
     }
   }
   try {
-    try {
-      let download = gDownloadManager.getDownload(aDownload.getAttribute("dlid"));
-      let mimeInfo = download.MIMEInfo;
-      if (mimeInfo.preferredAction == mimeInfo.useHelperApp) {
-        mimeInfo.launchWithFile(f);
-        return;
-      }
-    } catch (ex) {
-    }
     f.launch();
   } catch (ex) {
     // if launch fails, try sending it through the system's external
@@ -434,8 +420,6 @@ function Startup()
       e.preventDefault();
     }
   }, false);
-
-//@line 501 "/builds/slave/2.0-lnx-xr/build/toolkit/mozapps/downloads/content/downloads.js"
 }
 
 function Shutdown()
@@ -491,11 +475,11 @@ let gDownloadObserver = {
         }
         break;
       case "browser-lastwindow-close-granted":
-//@line 557 "/builds/slave/2.0-lnx-xr/build/toolkit/mozapps/downloads/content/downloads.js"
+//@line 535 "/builds/slave/rel-m-192-xr-lnx-bld/build/toolkit/mozapps/downloads/content/downloads.js"
         if (gDownloadManager.activeDownloadCount == 0) {
           setTimeout(gCloseDownloadManager, 0);
         }
-//@line 561 "/builds/slave/2.0-lnx-xr/build/toolkit/mozapps/downloads/content/downloads.js"
+//@line 539 "/builds/slave/rel-m-192-xr-lnx-bld/build/toolkit/mozapps/downloads/content/downloads.js"
         break;
     }
   }
@@ -642,25 +626,12 @@ function buildContextMenu(aEvent)
 
   return false;
 }
+
 ////////////////////////////////////////////////////////////////////////////////
 //// Drag and Drop
+
 var gDownloadDNDObserver =
 {
-  onDragStart: function (aEvent)
-  {
-    if (!gDownloadsView.selectedItem)
-      return;
-    var dl = gDownloadsView.selectedItem;
-    var f = getLocalFileFromNativePathOrUrl(dl.getAttribute("file"));
-    if (!f.exists())
-      return;
-
-    var dt = aEvent.dataTransfer;
-    dt.mozSetDataAt("application/x-moz-file", f, 0);
-    dt.effectAllowed = "copyMove";
-    dt.addElement(dl);
-  },
-
   onDragOver: function (aEvent)
   {
     var types = aEvent.dataTransfer.types;
@@ -1144,7 +1115,6 @@ function buildDownloadList(aForceBuild)
   gBuilder = setTimeout(function() {
     // Start building the list and select the first item
     stepListBuilder(1);
-    gDownloadsView.selectedIndex = 0;
 
     // We just tried to add a single item, so we probably need to enable
     updateClearListButton();
